=======
History
=======

0.0.1 (2019-02-16)
------------------

* First release on PyPI.

0.1.5 (2019-02-17)
-------------------

* Update README.rst.
* Update descriptions.
* Implement helper command (panw-utils).

0.1.6 (2019-02-17)
-------------------

* Fix bug in saved settings update

0.1.11 (2019-02-17)
-------------------

* Configure Travis CI

0.2.0 (2019-03-07)
-------------------

* Added get-panw-config

0.3.0 (2019-04-07)
-------------------

* Implement concurrency
* Redirect headers to sys.stderr to make grep friendly
* Add model, uptime and  software version to output

0.4.0 (2019-04-12)
-------------------

* Migrate from multi-processing to multi-threading

0.5.0 (2019-04-13)
-------------------

* Added run-panw-cmd

0.6.0 (2020-09-14)
-------------------

* Added Added status, MAC address, zone, virtual router and comment to get-panw-interfaces output
* Bumped requirements versions
